==> haskell-esqueleto-2.5.3.20180402-37-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: esqueleto
version: 2.6.0
id: esqueleto-2.6.0-HKUZIfHAkvDE0RXL8qURYd
key: esqueleto-2.6.0-HKUZIfHAkvDE0RXL8qURYd
license: BSD-3-Clause
copyright: (c) 2012-2016 Felipe Almeida Lessa
maintainer: cma@bitemyapp.com
author: Felipe Lessa
homepage: https://github.com/bitemyapp/esqueleto
synopsis: Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.
    .
    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)
    .
    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.
    .
    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.
category: Database
abi: 7acfdbf2aff7f7569b6573e086903a09
exposed: True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.SQLite
hidden-modules: Database.Esqueleto.Internal.PersistentImport
                Paths_esqueleto
import-dirs: /usr/lib/ghc-8.4.3/site-local/esqueleto-2.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/esqueleto-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/esqueleto-2.6.0
hs-libraries: HSesqueleto-2.6.0-HKUZIfHAkvDE0RXL8qURYd
depends:
    base-4.11.1.0 blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    bytestring-0.10.8.2 conduit-1.3.0.3-66nd3O923iS53T8SI1MATt
    monad-logger-0.3.28.5-Le3NyXl6lgo8CJsdX6ybpJ
    persistent-2.8.2-2FoKOvco4h3699ygtEWdD3
    resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 unliftio-0.2.7.0-EzYU21zpVB1AicVWwOW57E
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             conduit-1.3.0.3-66nd3O923iS53T8SI1MATt=d2e06181920a4035b53bbf7f067a9d71
             monad-logger-0.3.28.5-Le3NyXl6lgo8CJsdX6ybpJ=1cc2cf87695ad5c5895a81aa46ff58bd
             persistent-2.8.2-2FoKOvco4h3699ygtEWdD3=ba56452b7de5f8cf1529c889461dbb80
             resourcet-1.2.1-BNyr3sQ3rlV9LHFNVRp8Be=aed379ba96ef65280506356d2c555107
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unliftio-0.2.7.0-EzYU21zpVB1AicVWwOW57E=034ebba48206f0450a38c61533ce67c7
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html: /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-esqueleto-2.5.3.20180402-43-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-esqueleto.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: esqueleto
version: 2.6.0
id: esqueleto-2.6.0-4uyNeH0BH8uGLRVMly2wNm
key: esqueleto-2.6.0-4uyNeH0BH8uGLRVMly2wNm
license: BSD-3-Clause
copyright: (c) 2012-2016 Felipe Almeida Lessa
maintainer: cma@bitemyapp.com
author: Felipe Lessa
homepage: https://github.com/bitemyapp/esqueleto
synopsis: Type-safe EDSL for SQL queries on persistent backends.
description:
    @esqueleto@ is a bare bones, type-safe EDSL for SQL queries that works with unmodified @persistent@ SQL backends.  Its language closely resembles SQL, so you don'\''t have to learn new concepts, just new syntax, and it'\''s fairly easy to predict the generated SQL and optimize it for your backend. Most kinds of errors committed when writing SQL are caught as compile-time errors---although it is possible to write type-checked @esqueleto@ queries that fail at runtime.
    .
    @persistent@ is a library for type-safe data serialization.  It has many kinds of backends, such as SQL backends (@persistent-mysql@, @persistent-postgresql@, @persistent-sqlite@) and NoSQL backends (@persistent-mongoDB@). While @persistent@ is a nice library for storing and retrieving records, including with filters, it does not try to support some of the features that are specific to SQL backends.  In particular, @esqueleto@ is the recommended library for type-safe @JOIN@s on @persistent@ SQL backends.  (The alternative is using raw SQL, but that'\''s error prone and does not offer any composability.)
    .
    Currently, @SELECT@s, @UPDATE@s, @INSERT@s and @DELETE@s are supported. Not all SQL features are available, but most of them can be easily added (especially functions), so please open an issue or send a pull request if you need anything that is not covered by @esqueleto@ on <https://github.com/bitemyapp/esqueleto>.
    .
    The name of this library means \"skeleton\" in Portuguese and contains all three SQL letters in the correct order =).  It was inspired by Scala'\''s Squeryl but created from scratch.
category: Database
abi: f531bb682efd9aada567f1932fad98b6
exposed: True
exposed-modules:
    Database.Esqueleto Database.Esqueleto.Internal.Language
    Database.Esqueleto.Internal.Sql Database.Esqueleto.MySQL
    Database.Esqueleto.PostgreSQL Database.Esqueleto.SQLite
hidden-modules: Database.Esqueleto.Internal.PersistentImport
                Paths_esqueleto
import-dirs: /usr/lib/ghc-8.4.3/site-local/esqueleto-2.6.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/esqueleto-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/esqueleto-2.6.0
hs-libraries: HSesqueleto-2.6.0-4uyNeH0BH8uGLRVMly2wNm
depends:
    base-4.11.1.0 blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq
    bytestring-0.10.8.2 conduit-1.3.0.3-9CADFiQfBeM8QSPndyUfSD
    monad-logger-0.3.28.5-6DSapjoC7FDK8vptpersCR
    persistent-2.8.2-A4ExnB1CTb99JGEoPdHDfE
    resourcet-1.2.1-FuawklxGVUZGYJAiOqZc2P
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO text-1.2.3.0 time-1.8.0.2
    transformers-0.5.5.0 unliftio-0.2.7.0-LBAGL75YcVxIxq9URLYwPa
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             blaze-html-0.9.1.1-20cHaEyBGNsGxpPmCtOdMq=7047caae57386baf49e8a9f0b929d8b4
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             conduit-1.3.0.3-9CADFiQfBeM8QSPndyUfSD=4bca304bc332551afda8fa1e909cdcf2
             monad-logger-0.3.28.5-6DSapjoC7FDK8vptpersCR=450fd6490f70ee9cb9266ae8b4704fd3
             persistent-2.8.2-A4ExnB1CTb99JGEoPdHDfE=1d12c914d8b7820ccf4a6726b694cc37
             resourcet-1.2.1-FuawklxGVUZGYJAiOqZc2P=bbe5d0b69bce47d466850fbe63de03c7
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             time-1.8.0.2=976962cc6498b843f1efb5bef740838e
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             unliftio-0.2.7.0-LBAGL75YcVxIxq9URLYwPa=d812776a382a2fb32c4c5dc8a09c8ed6
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-esqueleto/html/esqueleto.haddock
haddock-html: /usr/share/doc/haskell-esqueleto/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
